@@ -44,10 +44,31 @@ template <class LockTraits>
 class TLTimeseriesT;
 
 namespace detail {
+
 template <typename LockTraits>
 class TLStatLink;
 template <typename LockTraits>
 class TLStatLinkPtr;
+
+/**
+ * FOR INTERNAL USE, controlled by the
+ * fb303_tcData_dont_update_on_read gflag.
+ *
+ * Return false if we shouldn't call update() on globalStat_
+ * when processing read requests.
+ * This mode fixes an aggregation bug of 100% / numBuckets drops
+ * of the aggregated value between the whole second boundary
+ * and the next call to TLTimeseries::aggregate().
+ *
+ * When this mode is enabled, you must call aggregate() once
+ * every few seconds or else it won't be able to decay properly
+ * if addValue()/addValueAggregated() calls stop altogether.
+ * ThreadCachedServiceData::startPublishThread() ensures this
+ * for the time series owned by it, and any custom wrappers
+ * should also make sure that they follow this rule.
+ */
+bool shouldUpdateGlobalStatOnRead();
+
 } // namespace detail
 
 /*
@@ -222,8 +243,13 @@ class ThreadLocalStatsT {
    * loop, fb303/TLStatsAsyncAggregator.h contains a class that can
    * periodically call aggregate() on a ThreadLocalStats from the
    * EventBase loop.
+   *
+   * Returns the count of thread local stats that were aggregated. Calling code
+   * can use it as a measure of the overhead of maintaining TL copies of the
+   * stats. The returned value is basically the same as the size of the tlStats_
+   * map.
    */
-  void aggregate();
+  uint64_t aggregate();
 
   /**
    * Call this function if you are about to transfer ownership of this
@@ -235,7 +261,7 @@ class ThreadLocalStatsT {
    * another thread, call swapThreads() to inform the ThreadLocalStats object
    * that it is okay if the next access occurs from a different thread.
    * You are still responsible for performing the correct external
-   * synchronization when transferring ownerhsip of this ThreadLocalStats
+   * synchronization when transferring ownership of this ThreadLocalStats
    * object to the other thread.
    *
    * A common use case for this is if you set up the ThreadLocalStats object in
